@@ -288,6 +288,7 @@ class ImagePipeline(
         pipeline_name: builtins.str,
         profile_name: builtins.str,
         additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+        ebs_volume_configuration: typing.Optional[typing.Union[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         email: typing.Optional[builtins.str] = None,
         image_recipe_version: typing.Optional[builtins.str] = None,
         instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -309,13 +310,14 @@ class ImagePipeline(
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
         :param additional_policies: Additional policies to add to the instance profile associated with the Instance Configurations.
+        :param ebs_volume_configuration: Configuration for the AMI's EBS volume.
         :param email: Email used to receive Image Builder Pipeline Notifications via SNS.
         :param image_recipe_version: Image recipe version (Default: 0.0.1).
         :param instance_types: List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ]).
         :param platform: Platform type Linux or Windows (Default: Linux).
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
-        :param user_data_script: UserData script that will override default one (if specified).
+        :param user_data_script: UserData script that will override default one (if specified). Default: - none
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571aeb5620d4)
@@ -332,6 +334,7 @@ class ImagePipeline(
             pipeline_name=pipeline_name,
             profile_name=profile_name,
             additional_policies=additional_policies,
+            ebs_volume_configuration=ebs_volume_configuration,
             email=email,
             image_recipe_version=image_recipe_version,
             instance_types=instance_types,
@@ -375,6 +378,7 @@ class ImagePipeline(
         "pipeline_name": "pipelineName",
         "profile_name": "profileName",
         "additional_policies": "additionalPolicies",
+        "ebs_volume_configuration": "ebsVolumeConfiguration",
         "email": "email",
         "image_recipe_version": "imageRecipeVersion",
         "instance_types": "instanceTypes",
@@ -398,6 +402,7 @@ class ImagePipelineProps:
         pipeline_name: builtins.str,
         profile_name: builtins.str,
         additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+        ebs_volume_configuration: typing.Optional[typing.Union[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty, typing.Dict[builtins.str, typing.Any]]] = None,
         email: typing.Optional[builtins.str] = None,
         image_recipe_version: typing.Optional[builtins.str] = None,
         instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -417,14 +422,17 @@ class ImagePipelineProps:
         :param pipeline_name: Name of the Image Pipeline.
         :param profile_name: Name of the instance profile that will be associated with the Instance Configuration.
         :param additional_policies: Additional policies to add to the instance profile associated with the Instance Configurations.
+        :param ebs_volume_configuration: Configuration for the AMI's EBS volume.
         :param email: Email used to receive Image Builder Pipeline Notifications via SNS.
         :param image_recipe_version: Image recipe version (Default: 0.0.1).
         :param instance_types: List of instance types used in the Instance Configuration (Default: [ 't3.medium', 'm5.large', 'm5.xlarge' ]).
         :param platform: Platform type Linux or Windows (Default: Linux).
         :param security_groups: List of security group IDs for the Infrastructure Configuration.
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
-        :param user_data_script: UserData script that will override default one (if specified).
+        :param user_data_script: UserData script that will override default one (if specified). Default: - none
         '''
+        if isinstance(ebs_volume_configuration, dict):
+            ebs_volume_configuration = _aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty(**ebs_volume_configuration)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edbdff4c88)
             check_type(argname="argument component_documents", value=component_documents, expected_type=type_hints["component_documents"])
@@ -437,6 +445,7 @@ class ImagePipelineProps:
             check_type(argname="argument pipeline_name", value=pipeline_name, expected_type=type_hints["pipeline_name"])
             check_type(argname="argument profile_name", value=profile_name, expected_type=type_hints["profile_name"])
             check_type(argname="argument additional_policies", value=additional_policies, expected_type=type_hints["additional_policies"])
+            check_type(argname="argument ebs_volume_configuration", value=ebs_volume_configuration, expected_type=type_hints["ebs_volume_configuration"])
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument image_recipe_version", value=image_recipe_version, expected_type=type_hints["image_recipe_version"])
             check_type(argname="argument instance_types", value=instance_types, expected_type=type_hints["instance_types"])
@@ -457,6 +466,8 @@ class ImagePipelineProps:
         }
         if additional_policies is not None:
             self._values["additional_policies"] = additional_policies
+        if ebs_volume_configuration is not None:
+            self._values["ebs_volume_configuration"] = ebs_volume_configuration
         if email is not None:
             self._values["email"] = email
         if image_recipe_version is not None:
@@ -549,6 +560,14 @@ class ImagePipelineProps:
         result = self._values.get("additional_policies")
         return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]], result)
 
+    @builtins.property
+    def ebs_volume_configuration(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty]:
+        '''Configuration for the AMI's EBS volume.'''
+        result = self._values.get("ebs_volume_configuration")
+        return typing.cast(typing.Optional[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty], result)
+
     @builtins.property
     def email(self) -> typing.Optional[builtins.str]:
         '''Email used to receive Image Builder Pipeline Notifications via SNS.'''
@@ -587,7 +606,10 @@ class ImagePipelineProps:
 
     @builtins.property
     def user_data_script(self) -> typing.Optional[builtins.str]:
-        '''UserData script that will override default one (if specified).'''
+        '''UserData script that will override default one (if specified).
+
+        :default: - none
+        '''
         result = self._values.get("user_data_script")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -624,6 +646,7 @@ def _typecheckingstub__6d6bcf5899c7945cb58b58346bf98d80366aa181448ff6906fb5571ae
     pipeline_name: builtins.str,
     profile_name: builtins.str,
     additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+    ebs_volume_configuration: typing.Optional[typing.Union[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     email: typing.Optional[builtins.str] = None,
     image_recipe_version: typing.Optional[builtins.str] = None,
     instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -653,6 +676,7 @@ def _typecheckingstub__d44c3e3f51e9feef4d0a0beb4a7aeeeb7d2d753e8a9bb21f5c19a8edb
     pipeline_name: builtins.str,
     profile_name: builtins.str,
     additional_policies: typing.Optional[typing.Sequence[_aws_cdk_aws_iam_ceddda9d.ManagedPolicy]] = None,
+    ebs_volume_configuration: typing.Optional[typing.Union[_aws_cdk_aws_imagebuilder_ceddda9d.CfnImageRecipe.EbsInstanceBlockDeviceSpecificationProperty, typing.Dict[builtins.str, typing.Any]]] = None,
     email: typing.Optional[builtins.str] = None,
     image_recipe_version: typing.Optional[builtins.str] = None,
     instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
